#include "public.h"

/*******************************************************************************
* 函 数 名       : delay_10us
* 函数功能		 : 延时函数，ten_us=1时，大约延时10us
* 输    入       : ten_us
* 输    出    	 : 无
*******************************************************************************/
void delay_10us(u16 ten_us)
{
	while(ten_us--);	
}

/*******************************************************************************
* 函 数 名       : delay_ms
* 函数功能		 : ms延时函数，ms=1时，大约延时1ms
* 输    入       : ms：ms延时时间
* 输    出    	 : 无
*******************************************************************************/
void delay_ms(u16 ms)
{
	u16 i,j;
	for(i=ms;i>0;i--)
		for(j=110;j>0;j--);
}

/*******************************************************************************
* 函 数 名       : auto_reset
* 函数功能		 : 接受到重启命令RESET!后，软复位MCU
* 输    入       : 无
* 输    出    	 : 0:检测到重启命令，1:未检测到重启命令
*******************************************************************************/
char __xdata reset_password[RESET_PASSWORD_LENGTH] = "RESET";
char __xdata receice_password[RESET_PASSWORD_LENGTH] = {0};
u8 auto_reset(u8 rec_data)
{
	for(u8 i=0;i<RESET_PASSWORD_LENGTH-1;i++)
	{
		receice_password[i] = receice_password[i+1]; 
	}
	receice_password[RESET_PASSWORD_LENGTH-1] = rec_data;

	for(u8 i=0;i<RESET_PASSWORD_LENGTH-1;i++)
	{
		if(receice_password[i]!= reset_password[i])
		{
			return 1;
		}
	}

	ISP_CONTR = 0x60; //软件复位并切换到系统ISP监控程序区开始执行程序
	return 0;
}

/*******************************************************************************
* 函 数 名      : rotate_left
* 函数功能      : 循环左移位
* 输    入      : 待移位数值value，移位位数shift
* 输    出      : 移位后的数值
*******************************************************************************/
u8 rotate_left(u8 value, u8 shift) {
    // 保存最高位
    u8 high_bit = value & 0x80;
    // 执行左移操作
    value <<= shift;
    // 将最高位循环到最低位
    value |= high_bit >> (8 - shift);
    return value;
}

/*******************************************************************************
* 函 数 名      : rotate_right
* 函数功能      : 循环右移位
* 输    入      : 待移位数值value，移位位数shift
* 输    出      : 移位后的数值
*******************************************************************************/
u8 rotate_right(u8 value, u8 shift) {
    // 保存最低位
    u8 low_bit = value & 0x01;
    // 执行右移操作
    value >>= shift;
    // 将最低位循环到最高位
    value |= low_bit << (8 - shift);
    return value;
}